# vsmask
VSMask aims to provide tools and functions to manage, create, and manipulate masks in VapourSynth.

"For further support, please leave any questions in the [IEW Discord server](https://discord.gg/qxTxVJGtst)


# Installation
vsmask is available on PyPi and can be installed with this simple command:"
```
pip install vsmask
```

# Dependencies 
The only hard dependencies are vsutil and an installation of VapourSynth R57 or higher.
However, for full functionality, you should make sure to also install [TCanny](https://github.com/HomeOfVapourSynthEvolution/VapourSynth-TCanny) and [TEdgeMask](https://github.com/dubhater/vapoursynth-tedgemask)
